customize/utils/utils library

Enums

AvailableGestures
Gestures available for the calendar.
CalendarFormat
Formats that the calendar can display.
StartingDayOfWeek
Days of the week that the calendar can start with.

Functions

getWeekdayNumber(StartingDayOfWeek weekday) → int
Returns a numerical value associated with given weekday.
isSameDay(DateTime? a, DateTime? b) → bool
Checks if two DateTime objects are the same day. Returns false if either of them is null.
isSameYear(DateTime? a, DateTime? b) → bool
normalizeDate(DateTime date) → DateTime
Returns date in UTC format, without its time part.

Typedefs

DayBuilder = Widget? Function(BuildContext context, DateTime day)
Signature for a function that creates a widget for a given day.
FocusedDayBuilder = Widget? Function(BuildContext context, DateTime day, DateTime focusedDay)
Signature for a function that creates a widget for a given day. Additionally, contains the currently focused day.
TextFormatter = String Function(DateTime date, dynamic locale)
Signature for a function returning text that can be localized and formatted with DateFormat.